Index: src/mathutils.c
===================================================================
--- src/mathutils.c	(revision 2f64b0eb35fd560567f08ac95d974014ea353fac)
+++ src/mathutils.c	(revision 5c4ec3cb6b9cafcc5a953f2176c6069ed02fe4e2)
@@ -93,5 +93,5 @@
 }
 
-smpl_t vec_sum(fvec_t *s) {
+smpl_t fvec_sum(fvec_t *s) {
   uint_t i,j;
   smpl_t tmp = 0.0f;
@@ -142,5 +142,5 @@
 }
 
-void vec_shift(fvec_t *s) {
+void fvec_shift(fvec_t *s) {
   uint_t i,j;
   //smpl_t tmp = 0.0f;
@@ -154,5 +154,5 @@
 }
 
-smpl_t vec_local_energy(fvec_t * f) {
+smpl_t fvec_local_energy(fvec_t * f) {
   smpl_t locE = 0.;
   uint_t i,j;
@@ -163,5 +163,5 @@
 }
 
-smpl_t vec_local_hfc(fvec_t * f) {
+smpl_t fvec_local_hfc(fvec_t * f) {
   smpl_t locE = 0.;
   uint_t i,j;
@@ -172,5 +172,5 @@
 }
 
-smpl_t vec_alpha_norm(fvec_t * DF, smpl_t alpha) {
+smpl_t fvec_alpha_norm(fvec_t * DF, smpl_t alpha) {
   smpl_t tmp = 0.;
   uint_t i,j;
@@ -181,5 +181,5 @@
 }
 
-void vec_dc_removal(fvec_t * mag) {
+void fvec_dc_removal(fvec_t * mag) {
     smpl_t mini = 0.;
     uint_t length = mag->length, i=0, j;
@@ -190,8 +190,8 @@
 }
 
-void vec_alpha_normalise(fvec_t * mag, uint_t alpha) {
+void fvec_alpha_normalise(fvec_t * mag, uint_t alpha) {
   smpl_t alphan = 1.;
   uint_t length = mag->length, i=0, j;
-  alphan = vec_alpha_norm(mag,alpha);
+  alphan = fvec_alpha_norm(mag,alpha);
   for (j=0;j<length;j++){
     mag->data[i][j] /= alphan;
@@ -199,5 +199,5 @@
 }
 
-void vec_add(fvec_t * mag, smpl_t threshold) {
+void fvec_add(fvec_t * mag, smpl_t threshold) {
   uint_t length = mag->length, i=0, j;
   for (j=0;j<length;j++) {
@@ -206,13 +206,13 @@
 }
 
-void vec_adapt_thres(fvec_t * vec, fvec_t * tmp,
+void fvec_adapt_thres(fvec_t * vec, fvec_t * tmp,
     uint_t post, uint_t pre) {
   uint_t length = vec->length, i=0, j;
   for (j=0;j<length;j++) {
-    vec->data[i][j] -= vec_moving_thres(vec, tmp, post, pre, j);
-  }
-}
-
-smpl_t vec_moving_thres(fvec_t * vec, fvec_t * tmpvec,
+    vec->data[i][j] -= fvec_moving_thres(vec, tmp, post, pre, j);
+  }
+}
+
+smpl_t fvec_moving_thres(fvec_t * vec, fvec_t * tmpvec,
     uint_t post, uint_t pre, uint_t pos) {
   smpl_t * medar = (smpl_t *)tmpvec->data[0];
@@ -237,8 +237,8 @@
       medar[k] = 0.; /* 0-padding at the end */
   }
-  return vec_median(tmpvec);
-}
-
-smpl_t vec_median(fvec_t * input) {
+  return fvec_median(tmpvec);
+}
+
+smpl_t fvec_median(fvec_t * input) {
   uint_t n = input->length;
   smpl_t * arr = (smpl_t *) input->data[0];
@@ -291,5 +291,5 @@
 }
 
-smpl_t vec_quadint(fvec_t * x,uint_t pos, uint_t span) {
+smpl_t fvec_quadint(fvec_t * x,uint_t pos, uint_t span) {
   smpl_t s0, s1, s2;
   uint_t x0 = (pos < span) ? pos : pos - span;
@@ -308,5 +308,5 @@
 }
 
-uint_t vec_peakpick(fvec_t * onset, uint_t pos) {
+uint_t fvec_peakpick(fvec_t * onset, uint_t pos) {
   uint_t i=0, tmp=0;
   /*for (i=0;i<onset->channels;i++)*/
Index: src/mathutils.h
===================================================================
--- src/mathutils.h	(revision 2f64b0eb35fd560567f08ac95d974014ea353fac)
+++ src/mathutils.h	(revision 5c4ec3cb6b9cafcc5a953f2176c6069ed02fe4e2)
@@ -97,7 +97,7 @@
  * a[n/2+1],...a[n],a[0]...,a[n/2]
  */
-void vec_shift(fvec_t *s);
+void fvec_shift(fvec_t *s);
 /** returns sum */
-smpl_t vec_sum(fvec_t *s);
+smpl_t fvec_sum(fvec_t *s);
 
 /** returns energy 
@@ -105,9 +105,9 @@
  * \bug mono 
  */
-smpl_t vec_local_energy(fvec_t * f);
+smpl_t fvec_local_energy(fvec_t * f);
 /** returns High Frequency Energy Content
  *
  * \bug mono */
-smpl_t vec_local_hfc(fvec_t * f);
+smpl_t fvec_local_hfc(fvec_t * f);
 /** return alpha norm.
  *
@@ -119,14 +119,14 @@
  * \bug should not use POW :(
  */
-smpl_t vec_alpha_norm(fvec_t * DF, smpl_t alpha);
+smpl_t fvec_alpha_norm(fvec_t * DF, smpl_t alpha);
 /**  dc(min) removal */
-void vec_dc_removal(fvec_t * mag);
+void fvec_dc_removal(fvec_t * mag);
 /**  alpha normalisation */
-void vec_alpha_normalise(fvec_t * mag, uint_t alpha);
+void fvec_alpha_normalise(fvec_t * mag, uint_t alpha);
 /** add a constant to all members of a vector */
-void vec_add(fvec_t * mag, smpl_t threshold);
+void fvec_add(fvec_t * mag, smpl_t threshold);
 
 /** compute adaptive threshold of input vector */ 
-void vec_adapt_thres(fvec_t * vec, fvec_t * tmp, 
+void fvec_adapt_thres(fvec_t * vec, fvec_t * tmp, 
     uint_t win_post, uint_t win_pre);
 /**  adaptative thresholding 
@@ -149,5 +149,5 @@
  * see SPARMS for explanation of post and pre
  */
-smpl_t vec_moving_thres(fvec_t * vec, fvec_t * tmp, 
+smpl_t fvec_moving_thres(fvec_t * vec, fvec_t * tmp, 
     uint_t win_post, uint_t win_pre, uint_t win_pos);
 
@@ -161,8 +161,8 @@
  *  available at http://ndevilla.free.fr/median/median/
  */
-smpl_t vec_median(fvec_t * input);
+smpl_t fvec_median(fvec_t * input);
 
 /** finds exact peak index by quadratic interpolation*/
-smpl_t vec_quadint(fvec_t * x, uint_t pos, uint_t span);
+smpl_t fvec_quadint(fvec_t * x, uint_t pos, uint_t span);
 
 /** Quadratic interpolation using Lagrange polynomial.
@@ -179,5 +179,5 @@
 
 /** returns 1 if X1 is a peak and positive */
-uint_t vec_peakpick(fvec_t * input, uint_t pos);
+uint_t fvec_peakpick(fvec_t * input, uint_t pos);
 
 /** convert frequency bin to midi value */
Index: src/onset/peakpick.c
===================================================================
--- src/onset/peakpick.c	(revision 2f64b0eb35fd560567f08ac95d974014ea353fac)
+++ src/onset/peakpick.c	(revision 5c4ec3cb6b9cafcc5a953f2176c6069ed02fe4e2)
@@ -161,6 +161,6 @@
 	t->win_pre   = 1;
 
-	t->thresholdfn = (aubio_thresholdfn_t)(vec_median); /* (fvec_mean); */
-	t->pickerfn = (aubio_pickerfn_t)(vec_peakpick);
+	t->thresholdfn = (aubio_thresholdfn_t)(fvec_median); /* (fvec_mean); */
+	t->pickerfn = (aubio_pickerfn_t)(fvec_peakpick);
 
 	t->scratch = new_fvec(t->win_post+t->win_pre+1,1);
Index: src/pitch/pitchyin.c
===================================================================
--- src/pitch/pitchyin.c	(revision 2f64b0eb35fd560567f08ac95d974014ea353fac)
+++ src/pitch/pitchyin.c	(revision 5c4ec3cb6b9cafcc5a953f2176c6069ed02fe4e2)
@@ -107,8 +107,8 @@
     if(tau > 4 && (yin->data[c][period] < tol) && 
         (yin->data[c][period] < yin->data[c][period+1])) {
-      return vec_quadint(yin,period,1);
+      return fvec_quadint(yin,period,1);
     }
   }
-  return vec_quadint(yin,fvec_min_elem(yin),1);
+  return fvec_quadint(yin,fvec_min_elem(yin),1);
   //return 0;
 }
Index: src/pitch/pitchyinfft.c
===================================================================
--- src/pitch/pitchyinfft.c	(revision 2f64b0eb35fd560567f08ac95d974014ea353fac)
+++ src/pitch/pitchyinfft.c	(revision 5c4ec3cb6b9cafcc5a953f2176c6069ed02fe4e2)
@@ -125,15 +125,15 @@
     //return tau;
     /* 3 point quadratic interpolation */
-    //return vec_quadint_min(yin,tau,1);
+    //return fvec_quadint_min(yin,tau,1);
     /* additional check for (unlikely) octave doubling in higher frequencies */
     if (tau>35) {
-      return vec_quadint(yin,tau,1);
+      return fvec_quadint(yin,tau,1);
     } else {
       /* should compare the minimum value of each interpolated peaks */
       halfperiod = FLOOR(tau/2+.5);
       if (yin->data[0][halfperiod] < tol)
-        return vec_quadint(yin,halfperiod,1);
+        return fvec_quadint(yin,halfperiod,1);
       else
-        return vec_quadint(yin,tau,1);
+        return fvec_quadint(yin,tau,1);
     }
   } else
Index: src/spectral/mfcc.c
===================================================================
--- src/spectral/mfcc.c	(revision 2f64b0eb35fd560567f08ac95d974014ea353fac)
+++ src/spectral/mfcc.c	(revision 5c4ec3cb6b9cafcc5a953f2176c6069ed02fe4e2)
@@ -108,5 +108,5 @@
 
   /* raise power */
-  //vec_pow (mf->in_dct, 3.);
+  //fvec_pow (mf->in_dct, 3.);
 
   /* zeros output */
Index: src/spectral/phasevoc.c
===================================================================
--- src/spectral/phasevoc.c	(revision 2f64b0eb35fd560567f08ac95d974014ea353fac)
+++ src/spectral/phasevoc.c	(revision 5c4ec3cb6b9cafcc5a953f2176c6069ed02fe4e2)
@@ -57,5 +57,5 @@
   fvec_weight(pv->data, pv->w);
   /* shift */
-  vec_shift(pv->data);
+  fvec_shift(pv->data);
   /* calculate fft */
   aubio_fft_do (pv->fft,pv->data,fftgrain);
@@ -67,5 +67,5 @@
   aubio_fft_rdo(pv->fft,fftgrain,pv->synth);
   /* unshift */
-  vec_shift(pv->synth);
+  fvec_shift(pv->synth);
   for (i=0; i<pv->channels; i++) {
     aubio_pvoc_addsynth(pv->synth->data[i],pv->synthold->data[i],
Index: src/tempo/beattracking.c
===================================================================
--- src/tempo/beattracking.c	(revision 2f64b0eb35fd560567f08ac95d974014ea353fac)
+++ src/tempo/beattracking.c	(revision 5c4ec3cb6b9cafcc5a953f2176c6069ed02fe4e2)
@@ -170,5 +170,5 @@
   /* find non-zero Rayleigh period */
   maxindex = fvec_max_elem (bt->acfout);
-  bt->rp = maxindex ? vec_quadint (bt->acfout, maxindex, 1) : 1;
+  bt->rp = maxindex ? fvec_quadint (bt->acfout, maxindex, 1) : 1;
   //rp = (maxindex==127) ? 43 : maxindex; //rayparam
   bt->rp = (maxindex == bt->acfout->length - 1) ? bt->rayparam : maxindex;      //rayparam
@@ -203,5 +203,5 @@
     phase = step - bt->lastbeat;
   } else {
-    phase = vec_quadint (bt->phout, maxindex, 1);
+    phase = fvec_quadint (bt->phout, maxindex, 1);
   }
   /* take back one frame delay */
@@ -305,5 +305,5 @@
     }
     fvec_weight (acfout, bt->gwv);
-    gp = vec_quadint (acfout, fvec_max_elem (acfout), 1);
+    gp = fvec_quadint (acfout, fvec_max_elem (acfout), 1);
     /*
        while(gp<32) gp =gp*2;
@@ -409,5 +409,5 @@
 {
   if (bt->timesig != 0 && bt->counter == 0 && bt->flagstep == 0) {
-    return 5168. / vec_quadint (bt->acfout, bt->bp, 1);
+    return 5168. / fvec_quadint (bt->acfout, bt->bp, 1);
   } else {
     return 0.;

Index: src/pitch/pitchmcomb.c
===================================================================
--- src/pitch/pitchmcomb.c	(revision 2f64b0eb35fd560567f08ac95d974014ea353fac)
+++ src/pitch/pitchmcomb.c	(revision 5c4ec3cb6b9cafcc5a953f2176c6069ed02fe4e2)
@@ -99,6 +99,6 @@
     newmag->data[i][j]=fftgrain->norm[i][j];
   /* detect only if local energy > 10. */
-  //if (vec_local_energy(newmag)>10.) {
-    //hfc = vec_local_hfc(newmag); //not used
+  //if (fvec_local_energy(newmag)>10.) {
+    //hfc = fvec_local_hfc(newmag); //not used
     aubio_pitchmcomb_spectral_pp(p, newmag);
     aubio_pitchmcomb_combdet(p,newmag);
@@ -132,6 +132,6 @@
     newmag->data[i][j]=fftgrain->norm[i][j];
   /* detect only if local energy > 10. */
-  if (vec_local_energy(newmag)>10.) {
-    /* hfc = vec_local_hfc(newmag); do not use */
+  if (fvec_local_energy(newmag)>10.) {
+    /* hfc = fvec_local_hfc(newmag); do not use */
     aubio_pitchmcomb_spectral_pp(p, newmag);
     aubio_pitchmcomb_combdet(p,newmag);
@@ -159,10 +159,10 @@
     mag->data[i][j] = newmag->data[i][j];
   }
-  vec_dc_removal(mag);               /* dc removal           */
-  vec_alpha_normalise(mag,p->alpha); /* alpha normalisation  */
+  fvec_dc_removal(mag);               /* dc removal           */
+  fvec_alpha_normalise(mag,p->alpha); /* alpha normalisation  */
   /* skipped */                      /* low pass filtering   */
-  /** \bug vec_moving_thres may write out of bounds */
-  vec_adapt_thres(mag,tmp,p->win_post,p->win_pre); /* adaptative threshold */
-  vec_add(mag,-p->threshold);        /* fixed threshold      */
+  /** \bug fvec_moving_thres may write out of bounds */
+  fvec_adapt_thres(mag,tmp,p->win_post,p->win_pre); /* adaptative threshold */
+  fvec_add(mag,-p->threshold);        /* fixed threshold      */
   {
     aubio_spectralpeak_t * peaks = (aubio_spectralpeak_t *)p->peaks;
@@ -269,9 +269,9 @@
   for (i=0;i<X->channels;i++)
     for (j=1;j<X->length-1;j++) {
-      ispeak = vec_peakpick(X,j);
+      ispeak = fvec_peakpick(X,j);
       if (ispeak) {
         count += ispeak;
         spectral_peaks[count-1].bin = j;
-        spectral_peaks[count-1].ebin = vec_quadint(X, j, 1) - 1.;
+        spectral_peaks[count-1].ebin = fvec_quadint(X, j, 1) - 1.;
       }
     }